@@ -490,11 +490,9 @@ rsvg_cairo_render_pango_layout (RsvgDrawingCtx * ctx, PangoLayout * layout, doub
     bbox.h = ink.height / (double)PANGO_SCALE;
     bbox.virgin = 0;
 
-    cairo_move_to (render->cr, x, y);
-
-    rsvg_bbox_insert (&render->bbox, &bbox);
-
     if (state->fill) {
+    cairo_move_to (render->cr, x, y);
+    rsvg_bbox_insert (&render->bbox, &bbox);
         _set_source_rsvg_paint_server (ctx,
                                        state->current_color,
                                        state->fill,
@@ -505,6 +503,8 @@ rsvg_cairo_render_pango_layout (RsvgDrawingCtx * ctx, PangoLayout * layout, doub
     }
 
     if (state->stroke) {
+        cairo_move_to (render->cr, x, y);
+        rsvg_bbox_insert (&render->bbox, &bbox);
         pango_cairo_layout_path (render->cr, layout);
 
         _set_source_rsvg_paint_server (ctx,
@@ -1082,6 +1082,8 @@ rsvg_cairo_get_image_of_node (RsvgDrawingCtx * ctx,
     rsvg_node_draw (drawable, ctx, 0);
     rsvg_state_pop (ctx);
 
+	/* no colorspace conversion necessary. this is just a convenient
+	   holder of ARGB data with a width, height, & stride */
     img = gdk_pixbuf_new_from_data (pixels,
                                     GDK_COLORSPACE_RGB,
                                     TRUE,
