@@ -29,9 +29,7 @@
 #include "rsvg-styles.h"
 #include "rsvg-image.h"
 
-#include <glib/gmem.h>
-#include <glib/gmessages.h>
-#include <glib/gstrfuncs.h>
+#include <glib.h>
 #include <string.h>
 #include <math.h>
 
@@ -463,8 +461,7 @@ rsvg_new_pattern (void)
     _rsvg_affine_identity (pattern->affine);
     pattern->super.set_atts = rsvg_pattern_set_atts;
     pattern->hasx = pattern->hasy = pattern->haswidth = pattern->hasheight = pattern->hasbbox =
-        pattern->hascbox = pattern->hasvbox = pattern->hasaspect = pattern->hastransform =
-        pattern->hasaspect = FALSE;
+        pattern->hascbox = pattern->hasvbox = pattern->hasaspect = pattern->hastransform = FALSE;
     return &pattern->super;
 }
 
