@@ -24,6 +24,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <locale.h>
 
 #include <gtk/gtk.h>
 #include <gdk/gdk.h>
@@ -630,9 +631,9 @@ view_pixbuf (ViewerCbInfo * info, int xid, const char *color)
 
 #ifdef ENABLE_XEMBED
     if (xid > 0) {
-        XReparentWindow (GDK_WINDOW_XDISPLAY (win->window),
-                         GDK_WINDOW_XID (win->window), xid, 0, 0);
-        XMapWindow (GDK_WINDOW_XDISPLAY (win->window), GDK_WINDOW_XID (win->window));
+        XReparentWindow (GDK_WINDOW_XDISPLAY (gtk_widget_get_window(win)),
+                         GDK_WINDOW_XID (gtk_widget_get_window(win)), xid, 0, 0);
+        XMapWindow (GDK_WINDOW_XDISPLAY (gtk_widget_get_window(win)), GDK_WINDOW_XID (gtk_widget_get_window(win)));
     }
 #endif
 }
@@ -692,6 +693,9 @@ main (int argc, char **argv)
         {NULL}
     };
 
+	/* Set the locale so that UTF-8 filenames work */
+	setlocale(LC_ALL, "");
+
     g_thread_init (NULL);
 
     info.pixbuf = NULL;
